<?php
/**
 * @name Server
 * @description Classe de base gérant les serveurs du plugin "Server"
 * @author Nicolas Biersart <n.biersart@esia-network.com>
 * @contributor
 * @copyright Nicolas Biersart 2012
 * @license
 * @esia 1.00
 * @version 1.0.0
 * @date 07/11/2012
 */
include_once SNMP_CLASS;
include_once LIB_SNMP;
include_once DEVICE_CLASS;
class FlowServerException extends DeviceException{ }
class FlowServer extends Device
{
	const OUTPUT_JSON = 1;
	const OUTPUT_OBJECT = 2;
	const OUTPUT_ARRAY = 3;
	protected $url;
	/*@NAME: __construct
	 *@IN: $dev un objet Device
	*@OUT: /
	*@TREAT: permet de construire un objet SyslogServer à partir d'un objet "Device"
	*@EXCEPTION: 	/
	*/
	public function __construct($dev=NULL)
	{
		if(get_class($dev) == 'Device')
		{
			parent::constructDevice($dev);
		}
		else
		{
			parent::__construct();
		}
	}
	public function setUrl($u)
	{
		$this->url = $u;
	}
	public function getUrl()
	{
		return $this->url;
	}
	private function formatOutput($data,$output)
	{
		if($output == FlowServer::OUTPUT_JSON)
		{
			return $data;
		}
		elseif($output == FlowServer::OUTPUT_ARRAY)
		{
			return json_decode($data,TRUE);
		}
		else
		{
			return json_decode($data);
		}
	}
	public function getCollectorsStatistic($channelid=null,$output=FlowServer::OUTPUT_OBJECT)
	{
		$params=null;
		if(!empty($channelid))
		{
			
		}
		//echo $this->url."/collector.php?action=lastdata&name=$name";
		$stat = file_get_contents($this->url."/stats.php?action=collectors$params");
		if($stat === FALSE)
		{
			$err = error_get_last();
			throw new FlowServerException("Host not found: ".$err['message']);
		}
		return $this->formatOutput($stat,$output);
	}
	public function getChannel($channelid=null,$output=FlowServer::OUTPUT_OBJECT)
	{
		$params="";
		if(!empty($channelid))
		{
			$params="&id=$channelid";
		}
		
		//echo $this->url."/collector.php?action=lastdata&name=$name";
		$stat = file_get_contents($this->url."/channel.php?action=getChannel$params");
		if($stat === FALSE)
		{
			$err = error_get_last();
			throw new FlowServerException("Host not found: ".$err['message']);
		}
		return $this->formatOutput($stat,$output);
	}
	public function getChannelStatistic($channelid=null,$type='bytes',$output=FlowServer::OUTPUT_OBJECT)
	{
		$params="type=$type";
		if(!empty($channelid))
		{
			$params="&id=$channelid";
		}
		
		//echo $this->url."/collector.php?action=lastdata&name=$name";
		$stat = file_get_contents($this->url."/stats.php?action=traffic&$params");
		if($stat === FALSE)
		{
			$err = error_get_last();
			throw new FlowServerException("Host not found: ".$err['message']);
		}
		return $this->formatOutput($stat,$output);
	}
	public function getCollector($channel='all',$output=FlowServer::OUTPUT_OBJECT)
	{
		$params="";
		if($channel !='all')
		{
			$params="&channel=$channel";
		}
		//echo $this->url."/collector.php?action=lastdata&name=$name";
		$stat = file_get_contents($this->url."/collector.php?action=get&channel=$name");
		if($stat === FALSE)
		{
			$err = error_get_last();
			throw new FlowServerException("Host not found: ".$err['message']);
		}
		return $this->formatOutput($stat,$output);
	}
	public function getDataCollector($collectorid,$output=FlowServer::OUTPUT_OBJECT)
	{
		//echo $this->url."/collector.php?action=lastdata&name=$name";
		$stat = file_get_contents($this->url."/collector.php?action=data&id=$collectorid");
		if($stat === FALSE)
		{
			$err = error_get_last();
			throw new FlowServerException("Host not found: ".$err['message']);
		}
		return $this->formatOutput($stat,$output);
	}
	public function executeCollector($ip,$name = 'TOP_10_IP_BYTES',$data='global',$type='all',$during='15min',$channel="",$output=FlowServer::OUTPUT_OBJECT)
	{
		$plugin = $name;
		if($data=='lan')
		{
			$plugin .= '_LAN';
		}
		elseif($data=='public')
		{
			$plugin .= '_PUBLIC';
		}
		if($type=='upload')
		{
			$plugin .= '_UPLOAD';
		}
		elseif($type=='download')
		{
			$plugin .= '_DOWNLOAD';
		}
		switch($during)
		{
			case '15min':$plugin .='_15MIN'; break;
			case '1h':$plugin .='_1H'; break;
			case '6h':$plugin .='_6H'; break;
			case '1d':$plugin .='_1D'; break;
			case '7d':$plugin .='_7D'; break;
			case '30d':$plugin .='_30D'; break;
			default: return null ; break;
		}
        $params = "plugin=$plugin";
        $params .= "&IP=$ip";
        if(!empty($channel))
		{
			$params.="&channel=$channel";
		}
	//echo $this->url."/collector.php?action=execute&".$params.'<br/>';
		$stat = file_get_contents($this->url."/collector.php?action=execute&".$params);
		if($stat === FALSE)
		{
			$err = error_get_last();
			throw new FlowServerException("Host not found: ".$err['message']);
		}
		return $this->formatOutput($stat,$output);
	}
	public function getLastTopIP($data='global',$type='all',$during='15min',$channel='all',$output=FlowServer::OUTPUT_OBJECT)
	{
		$name = 'TOP_10_IP_BYTES';
		if($data=='lan')
		{
			$name = 'TOP_10_IP_BYTES_LAN';
		}
		elseif($data=='public')
		{
			$name = 'TOP_10_IP_BYTES_PUBLIC';
		}
		if($type=='upload')
		{
			$name .= '_UPLOAD';
		}
		elseif($type=='download')
		{
			$name .= '_DOWNLOAD';
		}
		switch($during)
		{
			case '15min':$name .='_15MIN'; break;
			case '1h':$name .='_1H'; break;
			case '6h':$name .='_6H'; break;
			case '1d':$name .='_1D'; break;
			case '7d':$name .='_7D'; break;
			case '30d':$name .='_30D'; break;
			default: return null ; break;
		}
		//echo $this->url."/collector.php?action=lastdata&name=$name";
		$stat = file_get_contents($this->url."/collector.php?action=lastdata&name=$name");
		if($stat === FALSE)
		{
			$err = error_get_last();
			throw new FlowServerException("Host not found: ".$err['message']);
		}
		return $this->formatOutput($stat,$output);
	}
	public function getTopPort($during='15min',$channel='all',$output=FlowServer::OUTPUT_OBJECT)
	{
		$name = 'TOP_10_PORT';
		switch($during)
		{
			case '15min':$name .='_15MIN'; break;
			case '1h':$name .='_1H'; break;
			case '6h':$name .='_6H'; break;
			case '1d':$name .='_1D'; break;
			case '7d':$name .='_7D'; break;
			case '30d':$name .='_30D'; break;
			default: return null ; break;
		}
		//echo $this->url."/collector.php?action=lastdata&name=$name";
		$stat = file_get_contents($this->url."/collector.php?action=lastdata&name=$name");
		if($stat === FALSE)
		{
			$err = error_get_last();
			throw new FlowServerException("Host not found: ".$err['message']);
		}
		return $this->formatOutput($stat,$output);
	}
}
